;* ---------------------------------------------------------------------- *)
;*                _____ ______        __          __ _                    *)
;*               |_   _|  _ \ \      / /__  ___  / _| |_                  *)
;*                 | | | | | \ \ /\ / / __|/ _ \| |_| __|                 *)
;*                 | | | |_| |\ V  V /\__ \ (_) |  _| |_                  *)
;*                 |_| |____/  \_/\_/ |___/\___/|_|  \__|                 *)
;*                 GmbH                  www.tdwsoft.com                  *)
;* ---------------------------------------------------------------------- *)
;*                            TDWsoft GmbH                                *)
;*                   IT-Dienstleistung und Software                       *)
;* ---------------------------------------------------------------------- *)
;*                        F A C E  E L E M E N T S                        *)
;* ---------------------------------------------------------------------- *)
;*                          CONTACT ADDRESS                               *)
;*                                                                        *)
;* TDWsoft GmbH                   Tel <Zentrale>: +49 (0)721 2045560      *)
;* Jahnstrae 9                   Fax <Zentrale>: +49 (0)721 2045559      *)
;* D-76689 Karlsdorf-Neuthard     Internet: www.tdwsoft.com               *)
;*                                eMail: info@tdwsoft.de                  *)
;* ---------------------------------------------------------------------- *)

( IN-PACKAGE :FACE-ELEMENTS )
( USE-PACKAGE :OLI )

( DEFUN Tdwsoft-get-sys-var-tdwsite ()
   ( LET (( L_tdw_site ( SD-SYS-GETENV "TDW_SITE" ))
          ( L_site_list '( "TDW" "LMT" "LWE" "LHG" "HHA" "LBC" ))
         )

         ( IF L_tdw_site
             ( PROGN
               ( SETF L_tdw_site ( SD-STRING-UPCASE L_tdw_site ))
               ( COND (( MEMBER L_tdw_site L_site_list :TEST #'STRING= )
                        L_tdw_site
                      )
                      (( STRING= L_tdw_site "KEM" )
                        "LVT"
                      )
                      ( T
                        "TDW"
                      )
               )
             )
             "TDW"
         )
   )
)

;-------------------------------------
; 3D-Macrodatei in das Annotation laden
; Parameter 1: Verzeichnis
; Parameter 2: Datei
;-------------------------------------

( DEFUN tdwsoft-unitfile-universal-load ( P_path P_file )
  ( LET (( L_src_file ( FORMAT NIL "~Asrc\\~A.lsp" P_path P_file ))
         ( L_win_file ( FORMAT NIL "~Awin\\~A.dll" P_path P_file ))
         ( L_x64_file ( FORMAT NIL "~Ax64\\~A.dll" P_path P_file ))
         ( L_flag NIL )
        )

        ( UNLESS ( STRING= ( SD-SYS-GETENV "SDSRC" ) "SRC" )
            ( SETF L_flag T )
            ( IF (SD-OSDM64-P)
                ( IF ( SD-SEARCH-FILE L_x64_file )
                  ( LOAD L_x64_file )
                  ( SETF L_flag NIL )
                )
                ( IF ( SD-SEARCH-FILE L_win_file )
                  ( LOAD L_win_file )
                  ( SETF L_flag NIL )
                )
            )
        )

        ( UNLESS L_flag
           ( IF ( SD-SEARCH-FILE L_src_file )
              ( PROGN
                ( PRINT "Source-file will be loaded" )
                ( LOAD L_src_file )
              )
              ( PRINT ( FORMAT NIL "File ~A not exists" L_src_file ))
           )
        )
  )
)

;-------------------------------------
; 2D-Macrodatei in das Annotation laden
; Parameter 1: Verzeichnis
; Parameter 2: Datei
;-------------------------------------

( DEFUN Tdwsoft-unitfile-anno-macro-load ( P_path P_file )
  ( LET (( L_src_file ( FORMAT NIL "~Asrcm\\~A.mma" P_path P_file ))
         ( L_win_file ( FORMAT NIL "~Awin\\~A.msm" P_path P_file ))
         ( L_flag NIL )
        )

        ( IF ( SD-SEARCH-FILE L_win_file )
          ( SD-EXECUTE-ANNOTATOR-COMMAND :CMD ( FORMAT NIL "LOAD_MACRO '~A'"  L_win_file  ))
          ( SETF L_flag NIL )
        )

        ( UNLESS L_flag
           ( IF ( SD-SEARCH-FILE L_src_file )
              ( PROGN
                ( PRINT ( FORMAT T "Source-file ~A will be loaded" L_src_file ))
                ( SD-EXECUTE-ANNOTATOR-COMMAND :CMD ( FORMAT NIL "INPUT '~A'" L_src_file  ))
              )
              ( PRINT ( FORMAT NIL "File ~A not exists" L_src_file ))
           )
        )
  )
)

;-------------------------------------
; 2D-Macro-Conf-datei in das Annotation laden
; Parameter 1: Verzeichnis
; Parameter 2: Datei
;-------------------------------------

( DEFUN TDWsoft-unitfile-anno-conf-load ( P_module )
  ( LET (( L_file ( FORMAT NIL "~Aconf\\~A\\~Aconf.mma" ( OLI::SD-SYS-GETENV "FACE-ELEMENTS_PATH" ) P_module P_module ))
        )

        ( IF ( SD-SEARCH-FILE L_file )
           ( PROGN
             ( PRINT ( FORMAT T "Source-file ~A will be loaded" L_file ))
             ( SD-EXECUTE-ANNOTATOR-COMMAND :CMD ( FORMAT NIL "INPUT '~A'" L_file  ))
           )
           ( PRINT ( FORMAT NIL "File ~A not exists" L_file ))
        )
  )
)

;-------------------------------------
; Ermitteln der Konfigurationsdatei
; Parameter 1: Verzeichnis
; Parameter 2: Datei
;-------------------------------------

( DEFUN TDWsoft-get-conf-file ( P_module P_filename )
  ( LET (( L_conf_file ( FORMAT NIL "~A\\conf\\~A\\~A" ( OLI::SD-SYS-GETENV "FACE-ELEMENTS_PATH" ) P_module P_filename ))
         ( L_app_file ( FORMAT NIL "~A\\apps\\~A\\~A" ( OLI::SD-SYS-GETENV "FACE-ELEMENTS_PATH" ) P_module P_filename ))
        )

         ( IF ( SD-SEARCH-FILE L_conf_file )
           L_conf_file
           L_app_file
     )
   )
)

;-------------------------------------
; Ermitteln der Konfigurationsdatei
; Parameter 1: Verzeichnis
;-------------------------------------

( DEFUN TDWsoft-get-conf-dir ( P_module )
  ( LET (( L_conf_dir ( FORMAT NIL "~A\\conf\\~A\\" ( OLI::SD-SYS-GETENV "FACE-ELEMENTS_PATH" ) P_module ))
         ( L_app_dir ( FORMAT NIL "~A\\apps\\~A\\" ( OLI::SD-SYS-GETENV "FACE-ELEMENTS_PATH" ) P_module ))
        )

         ( IF ( SD-DIRECTORY-P L_conf_dir )
          L_conf_dir
                  L_app_dir
     )
   )
)

;-------------------------------------
; Anzeigetext aus Texttabelle lesen
; Parameter 1: Textnummer = Zeilennummer
; Parameter 2: Vorgabe
; Parameter 3: Sprachtabelle
;-------------------------------------

( DEFUN tdwsoft-read-text ( P_text_row P_vorgabe P_table )
   ( LET (( L_lang ( SD-INQ-CURRENT-LANGUAGE ))
          ( L_message NIL )
         )

         ( UNLESS ( OR ( EQ L_lang :GERMAN ) ( EQ L_lang :ENGLISH ))
                   ( SETF L_lang :ENGLISH )
         )

         ( WHEN ( SD-LOGICAL-TABLE-P P_table )

            ( SETF L_message ( SD-READ-LOGICAL-TABLE-CELL P_table
                                :PLIST ( LIST :INDEX ( FORMAT NIL "~A" P_text_row ))
                                :COLUMN L_lang )
            )
         )

         ; Kundenspezifische Anpassung

         ;( SETF L_message ( tdw-get-custom-message P_text_row P_vorgabe P_table ))

         ( UNLESS L_message ( SETF L_message P_vorgabe ))

         L_message

   )
)

;-------------------------------------
; Anzeigetext aus Textdatei lesen
; Parameter 1: Dateiname
;-------------------------------------

( DEFUN tdwsoft-read-file ( result-file &optional ( sep ";" ))
    (LET ((string-list nil)
         )

        ( WITH-OPEN-FILE ( my-file result-file :DIRECTION :INPUT)

     (LET (contents )
       (LOOP
        (LET ((text (READ-LINE my-file NIL 'EOF)))

          (IF (EQ text 'EOF)
              (RETURN)
              (PROGN
                ( WHEN Text
                    ( UNLESS ( OR ( STRING= ( SUBSEQ Text 0 1 ) "#" ) ( STRING= ( SUBSEQ Text 0 1 ) ";" ))
                      ( SETF text ( STRING-RIGHT-TRIM '( #\SPACE #\LINEFEED #\RETURN #\NEWLINE ) Text ))
                      ( WHEN Text
                        ( PUSH
                          ( SD-STRING-SPLIT TEXT sep )
                           string-list )
                      )
                    )
                )
              )
          ) ; End if
        ) ; Ende LET
       ) ; Ende Loop
     ) ; Ende LET contents
    ) ; Ende with-open-file
    string-list
    ) ; Ende LET string-list

) ; Ende Funktion

( DEFUN tdwsoft-get-custom-message ( P_text_row P_vorgabe P_table )
   ( LET (( L_return NIL )
          ( L_cnr ( SD-READ-LOGICAL-TABLE-CELL "tdwsoft-custom-language" :PLIST ( LIST :TDWSOFTNR P_text_row :MODULE P_table ) :COLUMN :CUSTOMNR ))
         )

         ;( WHEN ( FIND-PACKAGE :SCO )
         ; ( SETF L_return ( sco::sco-inq-lola-string L_cnr P_vorgabe ))
         ;)

         ; PTC/ CoCreate aufruf einfuegen

         ( UNLESS L_return
           ( SETF L_return P_vorgabe )
         )

      L_return
   )
)

;-------------------------------------
; Aufrufen der User Onlinehilfe
; Parameter 1: Modul
;-------------------------------------

( DEFUN tdwsoft-user-doku-call ( &REST P_module )
       ( LET* (( L_postfix ".pdf" )
               ( L_file NIL )
               ( L_file_german NIL )
               ( P_module NIL )    ; voruebergehend deaktiviert
              )

              ( IF P_module
                ( PROGN
                    ( SETF P_module ( ELT P_module 0 ))
                    ( SETF L_file ( FORMAT NIL "~A\\help\\user\\~A\\~A\\~A~A" ( OLI::SD-SYS-GETENV "FACE-ELEMENTS_PATH" ) ( SD-INQ-CURRENT-LANGUAGE ) P_module P_module L_postfix ))
                    ( SETF L_file_german ( FORMAT NIL "~A\\help\\user\\german\\~A\\~A~A" ( OLI::SD-SYS-GETENV "FACE-ELEMENTS_PATH" ) P_module P_module L_postfix ))
                )
                ( PROGN
                    ( SETF L_file ( FORMAT NIL "~A\\help\\user\\face-elements_user_~A~A" ( OLI::SD-SYS-GETENV "FACE-ELEMENTS_PATH" ) ( SD-INQ-CURRENT-LANGUAGE ) L_postfix ))
                    ( SETF L_file_german ( FORMAT NIL "~A\\help\\user\\face-elements_user_german~A" ( OLI::SD-SYS-GETENV "FACE-ELEMENTS_PATH" ) L_postfix ))
                )
              )

              ( PRINT L_file )

              ( IF ( SD-SEARCH-FILE L_file )
                ( PRINT ( SD-SYS-EXEC ( FORMAT NIL "start /B cmd /K \"~A\"" L_file )))
                ( IF ( SD-SEARCH-FILE L_file_german )
                   ( PRINT ( SD-SYS-EXEC ( FORMAT NIL "start /B cmd /K \"~A\"" L_file_german )))
                   ( SD-DISPLAY-MESSAGE ( OLI::SD-MULTI-LANG-STRING ( FORMAT NIL "~%No Helpfile ~A exists." L_file ) :GERMAN ( FORMAT NIL "~%Keine Hilfedatei ~A vorhanden." L_file )))
                )
              )
       )
)

;-------------------------------------
; Aufrufen der User Onlinehilfe
; Parameter 1: Modul
;-------------------------------------

( DEFUN tdwsoft-admin-doku-call ( &REST P_module )
       ( LET* (( L_postfix ".pdf" )
               ( L_file NIL )
               ( L_file_german NIL )
               ( P_module NIL )    ; voruebergehend deaktiviert
              )

             ( IF P_module
                ( PROGN
                    ( SETF P_module ( ELT P_module 0 ))
                    ( SETF L_file ( FORMAT NIL "~A\\help\\admin\\~A\\~A\\~A~A" ( OLI::SD-SYS-GETENV "FACE-ELEMENTS_PATH" ) ( SD-INQ-CURRENT-LANGUAGE ) P_module P_module L_postfix ))
                    ( SETF L_file_german ( FORMAT NIL "~A\\help\\german\\~A\\~A~A" ( OLI::SD-SYS-GETENV "FACE-ELEMENTS_PATH" ) P_module P_module L_postfix ))
                )
                ( PROGN
                    ( SETF L_file ( FORMAT NIL "~A\\help\\admin\\face-elements_admin_~A~A" ( OLI::SD-SYS-GETENV "FACE-ELEMENTS_PATH" ) ( SD-INQ-CURRENT-LANGUAGE ) L_postfix ))
                    ( SETF L_file_german ( FORMAT NIL "~A\\help\admin\\\face-elements_admin_german~A" ( OLI::SD-SYS-GETENV "FACE-ELEMENTS_PATH" ) L_postfix ))
                )
             )

             ( PRINT L_file )

             ( IF ( SD-SEARCH-FILE L_file )
               ( PRINT ( SD-SYS-EXEC ( FORMAT NIL "start /B cmd /k \"~A\"" L_file )))
               ( IF ( SD-SEARCH-FILE L_file_german )
                   ( PRINT ( SD-SYS-EXEC ( FORMAT NIL "start /B cmd /k \"~A\"" L_file_german )))
                   ( SD-DISPLAY-MESSAGE ( OLI::SD-MULTI-LANG-STRING ( FORMAT NIL "No Admin Helpfile ~A exists." L_file ) :GERMAN ( FORMAT NIL "Keine Admin Hilfedatei ~A vorhanden." L_file )))
               )
             )
       )
)

;-------------------------------------
; Aufrufen TDWsoft-Internetseite
;-------------------------------------

( DEFUN tdwsoft-show-homepage ( &REST P_args )

  ( OLI::SD-DISPLAY-URL ( FORMAT NIL "http://www.tdwsoft.com" ))

)


        ( SD-CREATE-LOGICAL-TABLE  "tdwsoft-custom-language"
         :COLUMNS     '( :TDWSOFTNR   :CUSTOMNR    :MODULE    )
         :TYPES       '( :NUMBER :NUMBER :STRING )
         :UNITS       '( NIL NIL NIL )
         :contents  '(
                       (  1 1340 "face-pass-message-table" )
                       (  2 1341 "face-pass-message-table" )
                       (  3 1342 "face-pass-message-table" )
                       (  4 1343 "face-pass-message-table" )
                       (  5 1344 "face-pass-message-table" )
                       (  6 1345 "face-pass-message-table" )
                       (  7 1346 "face-pass-message-table" )
                       (  8 1347 "face-pass-message-table" )
                       (  9 1348 "face-pass-message-table" )
                       ( 10 1349 "face-pass-message-table" )
                       ( 11 1350 "face-pass-message-table" )
                       ( 12 1351 "face-pass-message-table" )
                       ( 13 1352 "face-pass-message-table" )
                       ( 14 1353 "face-pass-message-table" )
                       ( 15 1354 "face-pass-message-table" )
                       ( 16 1355 "face-pass-message-table" )
                       ( 17 1356 "face-pass-message-table" )
                       ( 18 1357 "face-pass-message-table" )
                       ( 19 1358 "face-pass-message-table" )
                       ( 20 1359 "face-pass-message-table" )
                       ( 21 1360 "face-pass-message-table" )
                       ( 22 1361 "face-pass-message-table" )
                       ( 23 1362 "face-pass-message-table" )
                       ( 24 1363 "face-pass-message-table" )
                       ( 25 1364 "face-pass-message-table" )
                       ( 26 1365 "face-pass-message-table" )
                       ( 27 1366 "face-pass-message-table" )
                       ( 28 1367 "face-pass-message-table" )
                       ( 29 1368 "face-pass-message-table" )
                       ( 30 1369 "face-pass-message-table" )
                       ( 31 1370 "face-pass-message-table" )
                       ( 32 1370 "face-pass-message-table" )
                       ( 33 1371 "face-pass-message-table" )
                       ( 34 1372 "face-pass-message-table" )
                      )
        )

;-------------------------------------
; Laden der Face-Elements Module
; Parameter 1: Name der App
;-------------------------------------

( DEFUN Tdwsoft-load-app ( P_module &OPTIONAL ( P_application NIL ))
   ( LET (( L_file ( FORMAT NIL "~A\\apps\\~A\\~Acust.lsp" ( OLI::SD-SYS-GETENV "FACE-ELEMENTS_PATH" ) P_module P_module ))
          ( L_flag NIL )
         )

                 ( IF P_application
                   ( PROGN
                      ( COND (( AND ( SD-STRING= P_module "ling" ) ( SD-STRING= P_application "3DDOCU" ))
                                   ( IF ( OLI::SD-LICENSE-FREE-MODULE-ACTIVE-P "3DDOCU" )
                                                ( SETF L_flag T )
                                                        ( PROGN
                                                           ( STARTUP::ACTIVATE-3DDOCU )
                                                           ( Tdwsoft-load-app "ling" "3DDOCU" )
                                                        )
                                           )
                                 )
                                         ( T
                                           ( SETF L_flag T )
                                         )
                          )
                   )
                   ( PROGN
                     ( SETF L_flag T )
                   )
                 )

                 ( IF ( AND L_flag ( OLI::SD-SEARCH-FILE L_file ))
                         ( LOAD L_file )
                         ( FORMAT T "~%Error: File ~A of module: ~A doesn't exists. Please Check !!!" L_file P_module )
                  )
   )
)

;-------------------------------------
; Laden der Konfiguration
; Parameter 1: App
;-------------------------------------

( DEFUN Tdwsoft-unitfile-universal-conf-load ( P_module )
   ( LET (( L_file ( FORMAT NIL "~A\\conf\\~A\\~Aconf.lsp" ( OLI::SD-SYS-GETENV "FACE-ELEMENTS_PATH" ) P_module P_module ))
         )

          ( IF ( OLI::SD-SEARCH-FILE L_file )
         ( LOAD L_file )
         ( FORMAT T "~%Error: Conf-File ~A of module: ~A doesn't exists. Please Check !!!" L_file P_module )
      )
   )
)

( DEFUN Tdwsoft-create-lang-tab ( P_module )
  ( LET (( L_message_file ( FORMAT NIL "~A\\apps\\~A\\~Alang.txt" ( OLI::SD-SYS-GETENV "FACE-ELEMENTS_PATH" ) P_module P_module ))
         ( L_table ( FORMAT NIL "face-~A-message-table" P_module ))
        )

        ; Message-Tabelle erzeugen

        ( WHEN ( SD-LOGICAL-TABLE-P L_table ) ( SD-DESTROY-LOGICAL-TABLE L_table ))
                ( WHEN ( SD-DISPLAY-TABLE-P L_table ) ( SD-DESTROY-DISPLAY-TABLE L_table ))

        ( SD-CREATE-LOGICAL-TABLE L_table                 ; erzeugen der logischen Tabelle
                  :COLUMNS    '( :INDEX :GERMAN :ENGLISH :SPANISH  )      ; Spaltenidentifikation
                  ;:COLUMNNAMES '( "INDEX" "GERMAN" "ENGLISH" "SPANISH" )  ; Spaltennamen
                  :TYPES       '( :STRING    :STRING :STRING  :STRING  )     ; Typ des Spalteninhaltes
                  :UNITS       '(  NIL      NIL       NIL      NIL )         ; Einheit des Spalteninhaltes
                  :CONTENTS    ( tdwsoft-read-file L_message_file )    ; Inhalt der logischen Tabelle
        )

   ) ; Ende LET
)

;----------------------------------------------

( DEFUN tdwsoft-inq-obj-tree-list (P_object)
  (CONS P_object
        ( APPLY #'NCONC (MAPCAR #'tdwsoft-inq-obj-tree-list ( SD-INQ-OBJ-CHILDREN P_object )))
        )
)

;-------------------------------------
; LogFunktion
; Parameter 1: Stufe
; Parameter 2: App
; Parameter 3: Meldung
;-------------------------------------

( DEFUN Tdwsoft-log ( P_level P_app P_message )

  ( WHEN ( Tdwsoft-get-log )
    ( WHEN ( >= ( Tdwsoft-get-log-level ) P_level )
      ( WHEN ( OR ( SD-STRING= ( Tdwsoft-get-log-app ) "ALL" ) ( SD-STRING= ( Tdwsoft-get-log-app ) P_app ))
         ( LET (( L_file ( Tdwsoft-get-logfile ))
                ( L_fo NIL )
               )
               ( IF L_file
                   ( PROGN
                     ( SETF L_fo ( OPEN L_file
                            :DIRECTION :OUTPUT
                            :IF-EXISTS :APPEND
                            :IF-DOES-NOT-EXIST :CREATE
                                      )
                     )
                     ( FORMAT L_fo "~%~A:~A:~A" P_level P_app P_message )
                   )
                   ( PROGN
                     ( FORMAT T "~%~A:~A:~A" P_level P_app P_message )
                   )
               )
         )
      )
    )
  )
)

;-------------------------------------
; Ermitteln der Logdatei
; Rueckgabe: Namen der Logdatei / NIL = keine Logdatei
;-------------------------------------

( DEFUN Tdwsoft-get-logfile ()
   ( LET (( L_return NIL )
          ( L_log ( SD-SYS-GETENV "FACE-ELEMENTS_LOGFILE" ))
         )

         ( WHEN L_log
            ( SETF L_return L_log  )
         )

         L_return
    )
)

;-------------------------------------
; LogFunktion
; Rueckgabe: Logfunktion Ein= T /Aus = NIL
;-------------------------------------

( DEFUN Tdwsoft-get-log ()
   ( LET (( L_return NIL )
          ( L_log ( SD-SYS-GETENV "FACE-ELEMENTS_LOG" ))
         )

         ( WHEN L_log
            ( SETF L_return ( SD-STRING= L_log "1" ))
         )

         L_return
    )
)

;-------------------------------------
; Loescht die Logdatei
;-------------------------------------

( DEFUN Tdwsoft-delete-logfile ()
    ( LET (( L_file ( Tdwsoft-get-logfile ))
          )

          ( WHEN ( OLI::SD-SEARCH-FILE L_file )
             ( LISP::DELETE-FILE L_file )
          )
    )
)

( Tdwsoft-delete-logfile )

;-------------------------------------
; LogFunktion
; Rueckgabe: Loglevel
;-------------------------------------

( DEFUN Tdwsoft-get-log-level ()
   ( LET (( L_return 0 )
          ( L_level ( FORMAT NIL ( SD-SYS-GETENV "FACE-ELEMENTS_LOGLEVEL" )))
         )

         ( WHEN L_level
             ( IF ( SD-STRING= ( SD-STRING-UPCASE L_level ) ( SD-STRING-DOWNCASE L_level ))
                 ( SETF L_return ( READ-FROM-STRING L_level ))
                 ( SETF L_level 0 )
             )
         )

         L_return
    )
)

;-------------------------------------
; LogModul
; Rueckgabe: Logapp
;-------------------------------------

( DEFUN Tdwsoft-get-log-app ()
   ( LET (( L_return "ALL" )
          ( L_app ( FORMAT NIL ( SD-SYS-GETENV "FACE-ELEMENTS_LOGAPP" )))
         )

         ( WHEN L_app
           ( SETF L_return L_app )
         )

         L_return
    )
)

;-- end of file -------------------------------

( PRINT "tdwsoftenv.lsp loaded" )
